@@ -9,6 +9,10 @@ from .accounts import Accounts
 from .expense_types import ExpenseTypes
 from .attachments import Attachments
 from .expense_reports import ExpenseReports
+from .vendors import Vendors
+from .bills import Bills
+from .projects import Projects
+from .departments import Departments
 
 __all_ = [
     'ApiBase',
@@ -18,5 +22,9 @@ __all_ = [
     'Accounts',
     'ExpenseTypes',
     'Attachments',
-    'ExpenseReports'
+    'ExpenseReports',
+    'Vendors',
+    'Bills',
+    'Projects',
+    'Departments'
 ]
